=============================================
``psyclone.psyir.transformations.loop_trans``
=============================================

.. automodule:: psyclone.psyir.transformations.loop_trans

   .. contents::
      :local:

.. currentmodule:: psyclone.psyir.transformations.loop_trans


Classes
=======

- :py:class:`LoopTrans`:
  This abstract class is a base class for all transformations that act


.. autoclass:: LoopTrans
   :members:

   .. rubric:: Inheritance
   .. inheritance-diagram:: LoopTrans
      :parts: 1
